@@ -15,7 +15,7 @@ our @EXPORT = qw(
   getHangulName
   parseHangulName
 );
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 our @JamoL = ( # Initial (HANGUL CHOSEONG)
     "G", "GG", "N", "D", "DD", "R", "M", "B", "BB",
@@ -94,7 +94,7 @@ sub decomposeHangul {
 #
 sub composeHangul {
     my $str = shift;
-    return $str unless length $str;
+    if(! length $str) { return wantarray ? () : $str }
     my(@ret);
 
     foreach my $ch (unpack('U*', $str)) # Makes list! The string be short!
@@ -156,7 +156,7 @@ Lingua::KO::Hangul::Util - utility functions for Hangul Syllables
 
 =head1 DESCRIPTION
 
-A Hangul syllable consists of Hangul Jamo.
+A Hangul Syllable consists of Hangul Jamo.
 
 Hangul Jamo are classified into three classes:
 
@@ -164,7 +164,7 @@ Hangul Jamo are classified into three classes:
   JUNGSEONG (the medial sound)  as a vowel (V),
   JONGSEONG (the final sound)   as a trailing consonant (T).
 
-Any Hangul syllable is a composition of
+Any Hangul Syllable is a composition of
 
    i) CHOSEONG + JUNGSEONG (L + V)
 
@@ -184,7 +184,7 @@ Names of Hangul Syllables have a format of C<"HANGUL SYLLABLE %s">.
 
 Accepts unicode codepoint integer.
 
-If the specified codepoint is of a Hangul syllable,
+If the specified codepoint is of a Hangul Syllable,
 returns a list of codepoints (in a list context)
 or a UTF-8 string (in a scalar context)
 of its decomposition.
@@ -205,9 +205,9 @@ Otherwise, returns false (empty string or empty list).
 =item C<@codepoints_composed = composeHangul($src_string)>
 
 Any sequence of an initial Jamo C<L> and a medial Jamo C<V>
-is composed into a syllable C<LV>;
+is composed to a syllable C<LV>;
 then any sequence of a syllable C<LV> and a final Jamo C<T>
-is composed into a syllable C<LVT>.
+is composed to a syllable C<LVT>.
 
 Any characters other than Hangul Jamo and Hangul Syllables
 are unaffected.
@@ -224,7 +224,7 @@ are unaffected.
 
 =item C<$name = getHangulName($codepoint)>
 
-If the specified codepoint is of a Hangul syllable,
+If the specified codepoint is of a Hangul Syllable,
 returns its name; otherwise returns undef.
 
    getHangulName(0xAC00) returns "HANGUL SYLLABLE GA";
@@ -232,7 +232,7 @@ returns its name; otherwise returns undef.
 
 =item C<$codepoint = parseHangulName($name)>
 
-If the specified name is of a Hangul syllable,
+If the specified name is of a Hangul Syllable,
 returns its codepoint; otherwise returns undef. 
 
    parseHangulName("HANGUL SYLLABLE GEUL") returns 0xAE00;
